@@ -1,3 +1,3 @@
-def starting(self):
+def starting():
     pygame.init()
     clock = pygame.time.Clock()
